package com.ruoyi.bst.goods.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.goods.service.GoodsService;
import com.ruoyi.bst.sku.domain.Sku;
import com.ruoyi.bst.sku.domain.SkuQuery;
import com.ruoyi.bst.sku.domain.SkuVO;
import com.ruoyi.bst.sku.service.SkuService;
import com.ruoyi.bst.spec.domain.SpecQuery;
import com.ruoyi.bst.spec.domain.SpecVO;
import com.ruoyi.bst.spec.service.SpecAssembler;
import com.ruoyi.bst.spec.service.SpecService;
import com.ruoyi.bst.specValue.domain.SpecValue;
import com.ruoyi.bst.specValue.domain.SpecValueVO;
import com.ruoyi.bst.specValue.service.SpecValueService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.utils.collection.DiffListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.goods.mapper.GoodsMapper;
import com.ruoyi.bst.goods.domain.Goods;
import com.ruoyi.bst.goods.domain.GoodsVO;
import com.ruoyi.bst.goods.domain.GoodsQuery;
import org.springframework.transaction.support.TransactionTemplate;

/**
 * 商品Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@Service
public class GoodsServiceImpl implements GoodsService
{
    @Autowired
    private GoodsMapper goodsMapper;
    @Autowired
    private TransactionTemplate transactionTemplate;
    @Autowired
    private SpecService specService;
    @Autowired
    private SpecValueService specValueService;
    @Autowired
    private SkuService skuService;
    @Autowired
    private SpecAssembler specAssembler;

    /**
     * 查询商品
     *
     * @param id 商品主键
     * @return 商品
     */
    @Override
    public GoodsVO selectGoodsById(Long id)
    {
        return goodsMapper.selectGoodsById(id);
    }

    /**
     * 查询商品列表
     *
     * @param goods 商品
     * @return 商品
     */
    @Override
    public List<GoodsVO> selectGoodsList(GoodsQuery goods)
    {
        return goodsMapper.selectGoodsList(goods);
    }

    /**
     * 新增商品
     *
     * @param goodsVO 商品
     * @return 结果
     */
    @Override
    public int insertGoods(GoodsVO goodsVO)
    {
        goodsVO.setCreateTime(DateUtils.getNowDate());
        Integer result = transactionTemplate.execute(status -> {
            // 新增商品
            int i = goodsMapper.insertGoods(goodsVO);
            ServiceUtil.assertion(i != 1,"新增商品失败");

            // 保存规格项
            this.saveSpec(goodsVO);

            // 保存规格值
            this.saveSpecVal(goodsVO);

            // 保存SKU
            this.saveSku(goodsVO);

            return i;
        });
        return result;
    }

    private int saveSku(GoodsVO goodsVO) {
        List<SkuVO> skuList = goodsVO.getSkuVO();
        skuList.forEach(skuVO -> {
            skuVO.setGoodsId(goodsVO.getId());
        });
        // 通过商品ID查询旧数据
        List<SkuVO> oldList = skuService.selectListByGoodsId(goodsVO.getId());
        // 分离数据
        DiffListVO<SkuVO, SkuVO> diff = CollectionUtils.convertToDiffList(goodsVO.getSkuVO(), oldList, SkuVO::getGoodsId);
        // 增改删
        Integer result = transactionTemplate.execute(status -> {
            int rows = 0;
            if (diff.getAddCount() > 0) {
                int insert = skuService.batchInsert(diff.getAddList());
                ServiceUtil.assertion(insert != diff.getAddCount(), "新增成员失败");
                rows += insert;
            }
            if (diff.getUpdateCount() > 0) {
                int update = skuService.batchUpdate(diff.getUpdateList());
                ServiceUtil.assertion(update != diff.getUpdateCount(), "更新成员失败");
                rows += update;
            }
            if (diff.getDelCount() > 0) {
                int del = skuService.batchDelete(diff.getDelList());
                ServiceUtil.assertion(del != diff.getDelCount(), "删除成员失败");
                rows += del;
            }
            return rows;
        });
        return result == null ? 0 : result;
    }

    private int saveSpecVal(GoodsVO goodsVO) {
        // 新建一个规格值列表用于存储要插入的数据
        List<SpecValueVO> specValueVOList = new ArrayList<>();

        for (SpecVO specVO : goodsVO.getSpecVO()) {
            for (SpecValueVO specValueVO : specVO.getSpecValueVO()) {
                specValueVO.setSpecId(specVO.getId());
                specValueVOList.add(specValueVO);
            }
        }
        // 通过商品ID查询旧数据
        List<SpecValueVO> oldList = specValueService.selectListByGoodsId(goodsVO.getId());
        // 分离数据
        DiffListVO<SpecValueVO, SpecValueVO> diff = CollectionUtils.convertToDiffList(specValueVOList, oldList, SpecValueVO::getGoodsId);
        // 增改删
        Integer result = transactionTemplate.execute(status -> {
            int rows = 0;
            if (diff.getAddCount() > 0) {
                int insert = specValueService.batchInsert(diff.getAddList());
                ServiceUtil.assertion(insert != diff.getAddCount(), "新增成员失败");
                rows += insert;
            }
            if (diff.getUpdateCount() > 0) {
                int update = specValueService.batchUpdate(diff.getUpdateList());
                ServiceUtil.assertion(update != diff.getUpdateCount(), "更新成员失败");
                rows += update;
            }
            if (diff.getDelCount() > 0) {
                int del = specValueService.batchDelete(diff.getDelList());
                ServiceUtil.assertion(del != diff.getDelCount(), "删除成员失败");
                rows += del;
            }
            return rows;
        });

        return result == null ? 0 : result;
    }

    private int saveSpec(GoodsVO goodsVO) {
        List<SpecVO> specList = goodsVO.getSpecVO();
        specList.forEach(specVO -> {
            specVO.setGoodsId(goodsVO.getId());

        });
        // 通过商品ID查询旧数据
        List<SpecVO> oldList = specService.selectListByGoodsId(goodsVO.getId());
        // 分离数据
        DiffListVO<SpecVO, SpecVO> diff = CollectionUtils.convertToDiffList(goodsVO.getSpecVO(), oldList, SpecVO::getId);
        // 增改删
        Integer result = transactionTemplate.execute(status -> {
            int rows = 0;
            if (diff.getAddCount() > 0) {
                int insert = specService.batchInsert(diff.getAddList());
                ServiceUtil.assertion(insert != diff.getAddCount(), "新增成员失败");
                rows += insert;
            }
            if (diff.getUpdateCount() > 0) {
                int update = specService.batchUpdate(diff.getUpdateList());
                ServiceUtil.assertion(update != diff.getUpdateCount(), "更新成员失败");
                rows += update;
            }
            if (diff.getDelCount() > 0) {
                int del = specService.batchDelete(diff.getDelList());
                ServiceUtil.assertion(del != diff.getDelCount(), "删除成员失败");
                rows += del;
            }
            return rows;
        });

        return result == null ? 0 : result;
    }

    /**
     * 修改商品
     *
     * @param goods 商品
     * @return 结果
     */
    @Override
    public int updateGoods(Goods goods)
    {
        return goodsMapper.updateGoods(goods);
    }

    /**
     * 批量删除商品
     *
     * @param ids 需要删除的商品主键
     * @return 结果
     */
    @Override
    public int deleteGoodsByIds(List<Long> ids)
    {
        return goodsMapper.deleteGoodsByIds(ids);
    }

    /**
     * 查询爆灯次数列表
     *
     * @param id 爆灯次数列表主键
     * @return 爆灯次数列表
     */
    @Override
    public GoodsVO selectGoodsById(Long id, boolean scope)
    {
        if (id == null) {
            return null;
        }
        GoodsQuery query = new GoodsQuery();
        query.setId(id);
        query.setScope(scope);
        GoodsVO goods = this.selectOne(query);
        this.setValue(goods);
        return goods;
    }

    private void setValue(GoodsVO goods) {
        List<SpecVO> specVOList = specService.selectListByGoodsId(goods.getId());
        specAssembler.assembleSpecsValueList(specVOList);
        goods.setSpecVO(specVOList);
        SkuQuery skuQuery = new SkuQuery();
        skuQuery.setGoodsId(goods.getId());
        List<SkuVO> skuVOlist = skuService.selectSkuList(skuQuery);
        goods.setSkuVO(skuVOlist);
    }

    /**
     * 删除商品信息
     *
     * @param id 商品主键
     * @return 结果
     */
    @Override
    public int deleteGoodsById(Long id)
    {
        return goodsMapper.deleteGoodsById(id);
    }

    @Override
    public GoodsVO selectOne(GoodsQuery query) {
        PageHelper.startPage(1, 1);
        List<GoodsVO> notice = this.selectGoodsList(query);
        return CollectionUtils.firstElement(notice);
    }
}
