package com.ruoyi.bst.spec.service.impl;

import java.util.Collections;
import java.util.List;

import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.spec.mapper.SpecMapper;
import com.ruoyi.bst.spec.domain.Spec;
import com.ruoyi.bst.spec.domain.SpecVO;
import com.ruoyi.bst.spec.domain.SpecQuery;
import com.ruoyi.bst.spec.service.SpecService;

/**
 * 商品规格项Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@Service
public class SpecServiceImpl implements SpecService
{
    @Autowired
    private SpecMapper specMapper;

    /**
     * 查询商品规格项
     *
     * @param id 商品规格项主键
     * @return 商品规格项
     */
    @Override
    public SpecVO selectSpecById(Long id)
    {
        return specMapper.selectSpecById(id);
    }

    /**
     * 查询商品规格项列表
     *
     * @param spec 商品规格项
     * @return 商品规格项
     */
    @Override
    public List<SpecVO> selectSpecList(SpecQuery spec)
    {
        return specMapper.selectSpecList(spec);
    }

    /**
     * 新增商品规格项
     *
     * @param spec 商品规格项
     * @return 结果
     */
    @Override
    public SpecVO insertSpec(Spec spec)
    {
        return specMapper.insertSpec(spec);
    }

    /**
     * 修改商品规格项
     *
     * @param spec 商品规格项
     * @return 结果
     */
    @Override
    public int updateSpec(Spec spec)
    {
        return specMapper.updateSpec(spec);
    }

    /**
     * 批量删除商品规格项
     *
     * @param ids 需要删除的商品规格项主键
     * @return 结果
     */
    @Override
    public int deleteSpecByIds(List<Long> ids)
    {
        return specMapper.deleteSpecByIds(ids);
    }

    /**
     * 删除商品规格项信息
     *
     * @param id 商品规格项主键
     * @return 结果
     */
    @Override
    public int deleteSpecById(Long id)
    {
        return specMapper.deleteSpecById(id);
    }

    @Override
    public int batchInsert(List<SpecVO> specList) {
        return specMapper.batchInsert(specList);
    }

    @Override
    public List<SpecVO> selectListByGoodsId(Long goodsId) {
        if (goodsId == null) {
            return Collections.emptyList();
        }
        SpecQuery query = new SpecQuery();
        query.setGoodsId(goodsId);
        return specMapper.selectSpecList(query);
    }

    @Override
    public int batchUpdate(List<SpecVO> updateList) {
       if (CollectionUtils.isEmptyElement(updateList)) {
            return 0;
        }
        return specMapper.batchUpdate(updateList);
    }

    @Override
    public int batchDelete(List<? extends SpecVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return this.deleteSpecByIds(CollectionUtils.map(list, SpecVO::getId));
    }
}
