package com.ruoyi.bst.specValue.service.impl;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import com.ruoyi.bst.spec.domain.SpecQuery;
import com.ruoyi.bst.spec.domain.SpecVO;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.specValue.mapper.SpecValueMapper;
import com.ruoyi.bst.specValue.domain.SpecValue;
import com.ruoyi.bst.specValue.domain.SpecValueVO;
import com.ruoyi.bst.specValue.domain.SpecValueQuery;
import com.ruoyi.bst.specValue.service.SpecValueService;

/**
 * 商品规格值Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@Service
public class SpecValueServiceImpl implements SpecValueService
{
    @Autowired
    private SpecValueMapper specValueMapper;

    /**
     * 查询商品规格值
     *
     * @param id 商品规格值主键
     * @return 商品规格值
     */
    @Override
    public SpecValueVO selectSpecValueById(Long id)
    {
        return specValueMapper.selectSpecValueById(id);
    }

    /**
     * 查询商品规格值列表
     *
     * @param specValue 商品规格值
     * @return 商品规格值
     */
    @Override
    public List<SpecValueVO> selectSpecValueList(SpecValueQuery specValue)
    {
        return specValueMapper.selectSpecValueList(specValue);
    }

    /**
     * 新增商品规格值
     *
     * @param specValue 商品规格值
     * @return 结果
     */
    @Override
    public int insertSpecValue(SpecValue specValue)
    {
        return specValueMapper.insertSpecValue(specValue);
    }

    /**
     * 修改商品规格值
     *
     * @param specValue 商品规格值
     * @return 结果
     */
    @Override
    public int updateSpecValue(SpecValue specValue)
    {
        return specValueMapper.updateSpecValue(specValue);
    }

    /**
     * 批量删除商品规格值
     *
     * @param ids 需要删除的商品规格值主键
     * @return 结果
     */
    @Override
    public int deleteSpecValueByIds(List<Long> ids)
    {
        return specValueMapper.deleteSpecValueByIds(ids);
    }

    /**
     * 删除商品规格值信息
     *
     * @param id 商品规格值主键
     * @return 结果
     */
    @Override
    public int deleteSpecValueById(Long id)
    {
        return specValueMapper.deleteSpecValueById(id);
    }

    @Override
    public int batchInsert(List<SpecValueVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return specValueMapper.batchInsert(list);
    }

    @Override
    public int batchUpdate(List<? extends SpecValue> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return specValueMapper.batchUpdate(list);
    }

    @Override
    public int batchDelete(List<? extends SpecValue> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return this.deleteSpecValueByIds(CollectionUtils.map(list,SpecValue::getId));
    }

    @Override
    public List<SpecValueVO> selectListByGoodsId(Long goodsId) {
        if (goodsId == null) {
            return Collections.emptyList();
        }
        SpecValueQuery query = new SpecValueQuery();
        query.setGoodsId(goodsId);
        return specValueMapper.selectSpecValueList(query);
    }

}
