package com.ruoyi.web.bst;

import com.ruoyi.bst.sku.domain.Sku;
import com.ruoyi.bst.sku.domain.SkuQuery;
import com.ruoyi.bst.sku.domain.SkuVO;
import com.ruoyi.bst.sku.service.SkuService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.SnowFlakeUtil;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 商品SKUController
 *
 * @author ruoyi
 * @date 2025-05-30
 */
@RestController
@RequestMapping("/bst/sku")
public class SkuController extends BaseController
{
    @Autowired
    private SkuService skuService;

    /**
     * 查询商品SKU列表
     */
    @PreAuthorize("@ss.hasPermi('bst:sku:list')")
    @GetMapping("/list")
    public TableDataInfo list(SkuQuery query)
    {
        startPage();
        startOrderBy();
        List<SkuVO> list = skuService.selectSkuList(query);
        return getDataTable(list);
    }

    /**
     * 导出商品SKU列表
     */
    @PreAuthorize("@ss.hasPermi('bst:sku:export')")
    @Log(title = "商品SKU", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SkuQuery query)
    {
        List<SkuVO> list = skuService.selectSkuList(query);
        ExcelUtil<SkuVO> util = new ExcelUtil<SkuVO>(SkuVO.class);
        util.exportExcel(response, list, "商品SKU数据");
    }

    /**
     * 获取商品SKU详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:sku:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(skuService.selectSkuById(id));
    }

    /**
     * 新增商品SKU
     */
    @PreAuthorize("@ss.hasPermi('bst:sku:add')")
    @Log(title = "商品SKU", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Sku sku)
    {
        return toAjax(skuService.insertSku(sku));
    }

    /**
     * 修改商品SKU
     */
    @PreAuthorize("@ss.hasPermi('bst:sku:edit')")
    @Log(title = "商品SKU", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Sku sku)
    {
        return toAjax(skuService.updateSku(sku));
    }

    /**
     * 删除商品SKU
     */
    @PreAuthorize("@ss.hasPermi('bst:sku:remove')")
    @Log(title = "商品SKU", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(skuService.deleteSkuByIds(ids));
    }



    /**
     * 手动生成ID
     */
    @PreAuthorize("@ss.hasPermi('bst:sku:generateId')")
    @Log(title = "手动生成ID", businessType = BusinessType.OTHER)
    @GetMapping("generateId")
    public Long generateId()

    {
        return SnowFlakeUtil.newId();
    }


}
